@@ -64,7 +64,7 @@
 sequence2 <- function(nvec, from = 1L, by = 1L){
   # Sequence end values
   # If these cant be integers, then we need to work with doubles
-  seq_ends <- time_as_number(from) + (by * (pmax.int(nvec - 1, 0)))
+  seq_ends <- unclass(from) + (by * (pmax.int(nvec - 1, 0)))
   out_maybe_int <- all_integerable(seq_ends)
   # If from/by are integers and all sequence values < 2^31 then use sequence
   out_is_int <- is.integer(from) && is.integer(by) && out_maybe_int
